@@ -328,7 +328,11 @@ class BOM:
             reply = self.epic_api.get(
                 "part/?mfg=%s&mfg_pn=%s" % (self.manufacturer, assembly_name)
             )
-            if isinstance(reply, list) and isinstance(reply[0], dict):
+            if (
+                isinstance(reply, list)
+                and reply
+                and isinstance(reply[0], dict)
+            ):
                 old_assy = SimpleNamespace(**reply[0])
         except webapi.Error:
             pass
