@@ -468,13 +468,20 @@ class Vendor_Part(models.Model):
         )
 
     def html_link(self):
-        if self.vendor.search_url == "":
+        url =""
+        if self.vendor.search_url:
+            try:
+                url = self.vendor.search_url % {
+                    "mfg": escape(self.part.mfg),
+                    "mfg_pn": escape(self.part.mfg_pn),
+                    "vendor_pn": escape(self.vendor_pn),
+                }
+            except (KeyError, TypeError, ValueError):
+                pass
+
+        if not url:
             return escape(self.vendor_pn)
-        url = self.vendor.search_url % {
-            "mfg": escape(self.part.mfg),
-            "mfg_pn": escape(self.part.mfg_pn),
-            "vendor_pn": escape(self.vendor_pn),
-        }
+
         return '<a href="%s" target="part_lookup">%s</a>' % (
             url,
             self.vendor_pn,
