@@ -1,6 +1,6 @@
 #
-#   Copyright (c) 2014-2015, 2018, 2021, 2024 eGauge Systems LLC
-# 	1644 Conestoga St, Suite 2
+#   Copyright (c) 2014-2015, 2018, 2021, 2024-2025 eGauge Systems LLC
+# 	4805 Sterling Dr, Suite 1
 # 	Boulder, CO 80301
 # 	voice: 720-545-9767
 # 	email: davidm@egauge.net
@@ -544,6 +544,36 @@ class Part_Method_Tests(TestCase):
         self.assertEqual(p.avg_cost(), Decimal("0.001"))
 
 
+class Vendor_Part_Method_Tests(TestCase):
+    def test_html_link(self):
+        v = Vendor(search_url="")
+
+        p = Part()
+        vp = Vendor_Part(vendor_pn="VP001", part=p, vendor=v)
+
+        # empty_url patterns should yield the escaped vendor_pn:
+        self.assertEqual(vp.html_link(), "VP001")
+
+        # pattern causing KeyError should yield the escaped vendor_pn:
+        v.search_url = "%(bogus)"
+        self.assertEqual(vp.html_link(), "VP001")
+
+        # pattern causing TypeError should yield the escaped vendor_pn:
+        v.search_url = "%(vendor_pn)-cpn.html"
+        self.assertEqual(vp.html_link(), "VP001")
+
+        # pattern causing ValueError should yield the escaped vendor_pn:
+        v.search_url = "%(vendor_pn)"
+        self.assertEqual(vp.html_link(), "VP001")
+
+        # valid pattern should be expanded:
+        v.search_url = "https://host/%(vendor_pn)s.html"
+        self.assertEqual(
+            vp.html_link(),
+            '<a href="https://host/VP001.html" target="part_lookup">VP001</a>'
+        )
+
+
 class Access_Tests(TestCase):
     @classmethod
     def setup_part(cls):
